==> kdebase-3.1.tar.bz2: kdebase-3.1/kwin/kcmkwin/kwindecoration/pixmaps.h <==
/* 
	$Id: pixmaps.h,v 1.2 2001/06/06 10:04:21 gallium Exp $

	This is the new kwindecoration kcontrol module

	Copyright (c) 2001
		Karol Szwed <gallium@kde.org>
		http://gallium.n3.net/

	Supports new kwin configuration plugins, and titlebar button position
	modification via dnd interface.

	Based on original "kwintheme" (Window Borders) 
	Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>
*/


// Button pixmaps (screenshots of kde1 buttons which all people know well now)
// ============================================================================

/* XPM */
const char * button_close_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #FFFFFF",
"$	c #6E6E6E",
"%	c #F0F0F0",
"&	c #EFEFEF",
"*	c #EEEEEE",
"=	c #EDEDED",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@#$@@@@@@@@#$@@@@",
"%%%%#$$%%%%%%#$$%%%%",
"&&&&&#$$&&&&#$$&&&&&",
"&&&&&&#$$&&#$$&&&&&&",
"*******#$$#$$*******",
"========#$$$========",
"========#$$$========",
"-------#$$#$$-------",
";;;;;;#$$;;#$$;;;;;;",
";;;;;#$$;;;;#$$;;;;;",
">>>>#$$>>>>>>#$$>>>>",
",,,,#$,,,,,,,,#$,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};


/* XPM */
const char * button_help_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #6E6E6E",
"$	c #F0F0F0",
"%	c #FFFFFF",
"&	c #EFEFEF",
"*	c #EEEEEE",
"=	c #EDEDED",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@#####@@@@@@@",
"$$$$$$$##%%%##$$$$$$",
"&&&&&&&##%&&##%&&&&&",
"&&&&&&&&%%&&##%&&&&&",
"***********##%%*****",
"==========##%%======",
"=========##%%=======",
"---------##%--------",
";;;;;;;;;;%%;;;;;;;;",
";;;;;;;;;##;;;;;;;;;",
">>>>>>>>>##%>>>>>>>>",
",,,,,,,,,,%%,,,,,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};

/* XPM */
const char * button_maximize_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #FFFFFF",
"$	c #F0F0F0",
"%	c #6E6E6E",
"&	c #EFEFEF",
"*	c #EEEEEE",
"=	c #EDEDED",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@###########@@@@@",
"$$$$#%%%%%%%%%%$$$$$",
"&&&&#%&&&&&&&#%&&&&&",
"&&&&#%&&&&&&&#%&&&&&",
"****#%*******#%*****",
"====#%=======#%=====",
"====#%=======#%=====",
"----#%-------#%-----",
";;;;#%;;;;;;;#%;;;;;",
";;;;#%########%;;;;;",
">>>>#%%%%%%%%%%>>>>>",
",,,,,,,,,,,,,,,,,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};

/* XPM */
const char * button_menu_xpm[] = {
"20 20 21 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #000000",
"#	c #F1F1F1",
"$	c #FFFFFF",
"%	c #C3C3C3",
"&	c #F0F0F0",
"*	c #EFEFEF",
"=	c #FFFFC0",
"-	c #FFDCA8",
";	c #EEEEEE",
">	c #C05800",
",	c #EDEDED",
"'	c #ECECEC",
")	c #EBEBEB",
"!	c #808080",
"~	c #EAEAEA",
"{	c #E9E9E9",
"]	c #E8E8E8",
"^	c #E7E7E7",
"....................",
"....................",
"+++++++++@@+++++++++",
"####@@@@@$$@@@@@####",
"####@$$@%%%%@$$@####",
"&&&@@$$@@@@@@$$@&&&&",
"***@=@$$$$$$$$$@****",
"***@-@$%%%%%%$$@****",
";;;;>=@$$$$$$$$@;;;;",
",,,,@-@$%%%%%$$@,,,,",
",,,,@>=@$$$$$$$@,,,,",
"''''@@-@$%%%%$$@''''",
"))))@!>=@$$$$$$@))))",
"))))@$@-@$$$$$$@))))",
"~~~~@$!>@$$$$$$@~~~~",
"{{{{@$$!@$$$$$$@{{{{",
"{{{{@!!!!!!!!!!@{{{{",
"]]]]@@@@@@@@@@@@]]]]",
"^^^^^^^^^^^^^^^^^^^^",
"^^^^^^^^^^^^^^^^^^^^"};

/* XPM */
const char * button_minimize_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #F0F0F0",
"$	c #EFEFEF",
"%	c #EEEEEE",
"&	c #FFFFFF",
"*	c #EDEDED",
"=	c #6E6E6E",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@@@@@@@@@@@@@",
"####################",
"$$$$$$$$$$$$$$$$$$$$",
"$$$$$$$$$$$$$$$$$$$$",
"%%%%%%%%%&&&%%%%%%%%",
"*********&*=********",
"*********&==********",
"--------------------",
";;;;;;;;;;;;;;;;;;;;",
";;;;;;;;;;;;;;;;;;;;",
">>>>>>>>>>>>>>>>>>>>",
",,,,,,,,,,,,,,,,,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};


/* XPM */
const char * button_sticky_xpm[] = {
"20 20 17 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #F0F0F0",
"$	c #6E6E6E",
"%	c #EFEFEF",
"&	c #FFFFFF",
"*	c #EEEEEE",
"=	c #B7B7B7",
"-	c #EDEDED",
";	c #ECECEC",
">	c #EBEBEB",
",	c #EAEAEA",
"'	c #E9E9E9",
")	c #E8E8E8",
"!	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@@@@@@@@@@@@@",
"########$$#####$####",
"%%%%%%%%$&$%%%$$%%%%",
"%%%%%%%%$&&$$$&$%%%%",
"**&&&&&&$=&=&=&$****",
"--======$=&=&=&$----",
"--$$$$$$$==$=$=$----",
";;;;;;;;$=$$$$$$;;;;",
">>>>>>>>$$$>>>$$>>>>",
">>>>>>>>$$>>>>>$>>>>",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"''''''''''''''''''''",
"))))))))))))))))))))",
"!!!!!!!!!!!!!!!!!!!!",
"!!!!!!!!!!!!!!!!!!!!"};

/* XPM */
const char * button_spacer_xpm[] = {
"20 20 15 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #F0F0F0",
"$	c #6E6E6E",
"%	c #EFEFEF",
"&	c #EEEEEE",
"*	c #EDEDED",
"=	c #ECECEC",
"-	c #EBEBEB",
";	c #EAEAEA",
">	c #E9E9E9",
",	c #E8E8E8",
"'	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@@@@@@@@@@@@@",
"######$######$######",
"%%%%%$$%%%%%%$$%%%%%",
"%%%%$$%%%%%%%%$$%%%%",
"&&&$$&&&&&&&&&&$$&&&",
"**$$************$$**",
"***$$**********$$***",
"====$$========$$====",
"-----$$------$$-----",
"------$------$------",
";;;;;;;;;;;;;;;;;;;;",
">>>>>>>>>>>>>>>>>>>>",
">>>>>>>>>>>>>>>>>>>>",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"''''''''''''''''''''"};

/* XPM */
const char * titlebarspacer_xpm[] = {
"6 20 7 1",
" 	c None",
".	c #FFFFFF",
"+	c #E9E9E9",
"@	c #D3D3D3",
"#	c #BEBEBE",
"$	c #A8A8A8",
"%	c #929292",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%"};

// vim: ts=4

==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kwin/kcmkwin/kwindecoration/pixmaps.h <==
/* 
	$Id: pixmaps.h,v 1.4 2003/09/19 11:14:41 lunakl Exp $

	This is the new kwindecoration kcontrol module

	Copyright (c) 2001
		Karol Szwed <gallium@kde.org>
		http://gallium.n3.net/

	Supports new kwin configuration plugins, and titlebar button position
	modification via dnd interface.

	Based on original "kwintheme" (Window Borders) 
	Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/


// Button pixmaps (screenshots of kde1 buttons which all people know well now)
// ============================================================================

/* XPM */
const char * button_close_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #FFFFFF",
"$	c #6E6E6E",
"%	c #F0F0F0",
"&	c #EFEFEF",
"*	c #EEEEEE",
"=	c #EDEDED",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@#$@@@@@@@@#$@@@@",
"%%%%#$$%%%%%%#$$%%%%",
"&&&&&#$$&&&&#$$&&&&&",
"&&&&&&#$$&&#$$&&&&&&",
"*******#$$#$$*******",
"========#$$$========",
"========#$$$========",
"-------#$$#$$-------",
";;;;;;#$$;;#$$;;;;;;",
";;;;;#$$;;;;#$$;;;;;",
">>>>#$$>>>>>>#$$>>>>",
",,,,#$,,,,,,,,#$,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};


/* XPM */
const char * button_help_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #6E6E6E",
"$	c #F0F0F0",
"%	c #FFFFFF",
"&	c #EFEFEF",
"*	c #EEEEEE",
"=	c #EDEDED",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@#####@@@@@@@",
"$$$$$$$##%%%##$$$$$$",
"&&&&&&&##%&&##%&&&&&",
"&&&&&&&&%%&&##%&&&&&",
"***********##%%*****",
"==========##%%======",
"=========##%%=======",
"---------##%--------",
";;;;;;;;;;%%;;;;;;;;",
";;;;;;;;;##;;;;;;;;;",
">>>>>>>>>##%>>>>>>>>",
",,,,,,,,,,%%,,,,,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};

/* XPM */
const char * button_maximize_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #FFFFFF",
"$	c #F0F0F0",
"%	c #6E6E6E",
"&	c #EFEFEF",
"*	c #EEEEEE",
"=	c #EDEDED",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@###########@@@@@",
"$$$$#%%%%%%%%%%$$$$$",
"&&&&#%&&&&&&&#%&&&&&",
"&&&&#%&&&&&&&#%&&&&&",
"****#%*******#%*****",
"====#%=======#%=====",
"====#%=======#%=====",
"----#%-------#%-----",
";;;;#%;;;;;;;#%;;;;;",
";;;;#%########%;;;;;",
">>>>#%%%%%%%%%%>>>>>",
",,,,,,,,,,,,,,,,,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};

/* XPM */
const char * button_menu_xpm[] = {
"20 20 21 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #000000",
"#	c #F1F1F1",
"$	c #FFFFFF",
"%	c #C3C3C3",
"&	c #F0F0F0",
"*	c #EFEFEF",
"=	c #FFFFC0",
"-	c #FFDCA8",
";	c #EEEEEE",
">	c #C05800",
",	c #EDEDED",
"'	c #ECECEC",
")	c #EBEBEB",
"!	c #808080",
"~	c #EAEAEA",
"{	c #E9E9E9",
"]	c #E8E8E8",
"^	c #E7E7E7",
"....................",
"....................",
"+++++++++@@+++++++++",
"####@@@@@$$@@@@@####",
"####@$$@%%%%@$$@####",
"&&&@@$$@@@@@@$$@&&&&",
"***@=@$$$$$$$$$@****",
"***@-@$%%%%%%$$@****",
";;;;>=@$$$$$$$$@;;;;",
",,,,@-@$%%%%%$$@,,,,",
",,,,@>=@$$$$$$$@,,,,",
"''''@@-@$%%%%$$@''''",
"))))@!>=@$$$$$$@))))",
"))))@$@-@$$$$$$@))))",
"~~~~@$!>@$$$$$$@~~~~",
"{{{{@$$!@$$$$$$@{{{{",
"{{{{@!!!!!!!!!!@{{{{",
"]]]]@@@@@@@@@@@@]]]]",
"^^^^^^^^^^^^^^^^^^^^",
"^^^^^^^^^^^^^^^^^^^^"};

/* XPM */
const char * button_minimize_xpm[] = {
"20 20 16 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #F0F0F0",
"$	c #EFEFEF",
"%	c #EEEEEE",
"&	c #FFFFFF",
"*	c #EDEDED",
"=	c #6E6E6E",
"-	c #ECECEC",
";	c #EBEBEB",
">	c #EAEAEA",
",	c #E9E9E9",
"'	c #E8E8E8",
")	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@@@@@@@@@@@@@",
"####################",
"$$$$$$$$$$$$$$$$$$$$",
"$$$$$$$$$$$$$$$$$$$$",
"%%%%%%%%%&&&%%%%%%%%",
"*********&*=********",
"*********&==********",
"--------------------",
";;;;;;;;;;;;;;;;;;;;",
";;;;;;;;;;;;;;;;;;;;",
">>>>>>>>>>>>>>>>>>>>",
",,,,,,,,,,,,,,,,,,,,",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"))))))))))))))))))))",
"))))))))))))))))))))"};


/* XPM */
const char * button_on_all_desktops_xpm[] = {
"20 20 17 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #F0F0F0",
"$	c #6E6E6E",
"%	c #EFEFEF",
"&	c #FFFFFF",
"*	c #EEEEEE",
"=	c #B7B7B7",
"-	c #EDEDED",
";	c #ECECEC",
">	c #EBEBEB",
",	c #EAEAEA",
"'	c #E9E9E9",
")	c #E8E8E8",
"!	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@@@@@@@@@@@@@",
"########$$#####$####",
"%%%%%%%%$&$%%%$$%%%%",
"%%%%%%%%$&&$$$&$%%%%",
"**&&&&&&$=&=&=&$****",
"--======$=&=&=&$----",
"--$$$$$$$==$=$=$----",
";;;;;;;;$=$$$$$$;;;;",
">>>>>>>>$$$>>>$$>>>>",
">>>>>>>>$$>>>>>$>>>>",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"''''''''''''''''''''",
"))))))))))))))))))))",
"!!!!!!!!!!!!!!!!!!!!",
"!!!!!!!!!!!!!!!!!!!!"};

/* XPM */
const char * button_spacer_xpm[] = {
"20 20 15 1",
" 	c None",
".	c #F3F3F3",
"+	c #F2F2F2",
"@	c #F1F1F1",
"#	c #F0F0F0",
"$	c #6E6E6E",
"%	c #EFEFEF",
"&	c #EEEEEE",
"*	c #EDEDED",
"=	c #ECECEC",
"-	c #EBEBEB",
";	c #EAEAEA",
">	c #E9E9E9",
",	c #E8E8E8",
"'	c #E7E7E7",
"....................",
"....................",
"++++++++++++++++++++",
"@@@@@@@@@@@@@@@@@@@@",
"@@@@@@@@@@@@@@@@@@@@",
"######$######$######",
"%%%%%$$%%%%%%$$%%%%%",
"%%%%$$%%%%%%%%$$%%%%",
"&&&$$&&&&&&&&&&$$&&&",
"**$$************$$**",
"***$$**********$$***",
"====$$========$$====",
"-----$$------$$-----",
"------$------$------",
";;;;;;;;;;;;;;;;;;;;",
">>>>>>>>>>>>>>>>>>>>",
">>>>>>>>>>>>>>>>>>>>",
",,,,,,,,,,,,,,,,,,,,",
"''''''''''''''''''''",
"''''''''''''''''''''"};

/* XPM */
const char * titlebarspacer_xpm[] = {
"6 20 7 1",
" 	c None",
".	c #FFFFFF",
"+	c #E9E9E9",
"@	c #D3D3D3",
"#	c #BEBEBE",
"$	c #A8A8A8",
"%	c #929292",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%",
".+@#$%"};

// vim: ts=4
